<?php
/**
 * @package     gantry
 * @subpackage  features
 * @version		1.5.2 May 10, 2010
 * @author		RocketTheme http://www.rockettheme.com
 * @copyright 	Copyright (C) 2007 - 2010 RocketTheme, LLC
 * @license		http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 only
 *
 * Gantry uses the Joomla Framework (http://www.joomla.org), a GNU/GPLv2 content management system
 *
 */

defined('JPATH_BASE') or die();

gantry_import('core.gantryfeature');


/**
 * @package     gantry
 * @subpackage  features
 */
class GantryFeatureRotator extends GantryFeature {
    var $_feature_name = 'rotator';

	function init() {
		global $gantry;
		
		if ($this->get('enabled')) {
			$path = $gantry->_working_params['rotator-backgrounds']['attributes']['path'];
	        $path = str_replace("__TEMPLATE__", $gantry->templateUrl, $path);
			$bgs = implode("', '", explode(',', $gantry->get('rotator-backgrounds')));
			$gantry->addScript('gantry-rotator.js');
			$gantry->addInlineScript("
				var GantryRotatorList = {'backgrounds': ['".$bgs."'], 'path': '".$path."'};
				window.addEvent('domready', function() {
					var GantryRotatorFx = new GantryRotator('rt-rotator', {
						'controls': ".$gantry->get('rotator-controls').",
						'autoplay': ".$gantry->get('rotator-autoplay').",
						'delay': ".$gantry->get('rotator-delay').",
						'interval': ".$gantry->get('rotator-interval')."
					});
				});
			");
		}
		
	}

    function isEnabled() {		
		return $this->get('enabled');
    }

    function isInPosition($position){
        if ($position == 'rotator') return true;
		else return false;
    }

	function isOrderable(){
		return false;
	}
	
	function render($position = "rotator"){
		$content = $this->_getContent();
		$render = "";
		
		if ($content) {
			$i = 0;
			foreach($content as $text) {
				if (!$i) $cls = " first";
				else if ($i == count($content) - 1) $cls = " last";
				else $cls = "";
				
				$render .= '<div class="rotator-desc'.$cls.'">'.$text->introtext.'</div>';
				$i++;
			}
		}
	    return $render;
	}
	
	function _getContent(){
		require_once (JPATH_SITE.DS.'components'.DS.'com_content'.DS.'helpers'.DS.'route.php');
		
		global $mainframe;
		
		if ($this->get('category', 0) == 0 && $this->get('section', 0) == 0) return false;
		
		$cparams	    =& $mainframe->getParams('com_content');

		$db			    =& JFactory::getDBO();
		$user		    =& JFactory::getUser();
		$userId		    = (int) $user->get('id');

		$count		    = 40; 
		$catid		    = $this->get('category', 0);
		$secid		    = $this->get('section', 0);
		$show_front	    = 1;
		$aid		    = 0;
		$content_type   = 'joomla';
		$ordering       = $this->get('order');
		$cid            = NULL;
		$user_id        = '';

		$contentConfig  = &JComponentHelper::getParams( 'com_content' );
		$access		    = !$contentConfig->get('shownoauth');

		$nullDate	    = $db->getNullDate();

		$date =& JFactory::getDate();
		$now = $date->toMySQL();
		$where = '';
		
		// User Filter
		switch ($user_id)
		{
			case 'by_me':
				$where .= ' AND (a.created_by = ' . (int) $userId . ' OR a.modified_by = ' . (int) $userId . ')';
				break;
			case 'not_me':
				$where .= ' AND (a.created_by <> ' . (int) $userId . ' AND a.modified_by <> ' . (int) $userId . ')';
				break;
		}
		
		// ensure should be published
		$where .= " AND ( a.publish_up = ".$db->Quote($nullDate)." OR a.publish_up <= ".$db->Quote($now)." )";
		$where .= " AND ( a.publish_down = ".$db->Quote($nullDate)." OR a.publish_down >= ".$db->Quote($now)." )";
		
	    // ordering
		switch ($ordering) {
			case 'date' :
				$orderby = 'a.created ASC';
				break;
			case 'rdate' :
				$orderby = 'a.created DESC';
				break;
			case 'alpha' :
				$orderby = 'a.title';
				break;
			case 'ralpha' :
				$orderby = 'a.title DESC';
				break;
			case 'order' :
				$orderby = 'a.ordering';
				break;
			default :
				$orderby = 'a.id DESC';
				break;
		}
				
		// content specific stuff
        if ($content_type=='joomla') {
            // start Joomla specific
            
            $catCondition = '';
            $secCondition = '';

            if ($show_front != 2) {
        		if ($catid)
        		{
        			$ids = explode( ',', $catid );
        			JArrayHelper::toInteger( $ids );
        			$catCondition = ' AND (cc.id=' . implode( ' OR cc.id=', $ids ) . ')';
        		}
        		if ($secid)
        		{
        			$ids = explode( ',', $secid );
        			JArrayHelper::toInteger( $ids );
        			$secCondition = ' AND (s.id=' . implode( ' OR s.id=', $ids ) . ')';
        		}
        	}
		
    		// Content Items only
    		$query = 'SELECT a.*, ' .
    			' CASE WHEN CHAR_LENGTH(a.alias) THEN CONCAT_WS(":", a.id, a.alias) ELSE a.id END as slug,'.
    			' CASE WHEN CHAR_LENGTH(cc.alias) THEN CONCAT_WS(":", cc.id, cc.alias) ELSE cc.id END as catslug'.
    			' FROM #__content AS a' .
    			($show_front == '0' ? ' LEFT JOIN #__content_frontpage AS f ON f.content_id = a.id' : '') .
    			($show_front == '2' ? ' INNER JOIN #__content_frontpage AS f ON f.content_id = a.id' : '') .
    			' INNER JOIN #__categories AS cc ON cc.id = a.catid' .
    			' INNER JOIN #__sections AS s ON s.id = a.sectionid' .
    			' WHERE a.state = 1'. $where .' AND s.id > 0' .
    			($access ? ' AND a.access <= ' .(int) $aid. ' AND cc.access <= ' .(int) $aid. ' AND s.access <= ' .(int) $aid : '').
    			($catid && $show_front != 2 ? $catCondition : '').
    			($secid && $show_front != 2 ? $secCondition : '').
    			($show_front == '0' ? ' AND f.content_id IS NULL ' : '').
    			' AND s.published = 1' .
    			' AND cc.published = 1' .
    			' ORDER BY '. $orderby;
    		// end Joomla specific
	    }
			
		$db->setQuery($query, 0, $count);
		
		$rows = $db->loadObjectList();

        $i=0;
		$lists	= array();
		
		if (is_array($rows) && count($rows)>0) {
    		foreach ( $rows as $row )
    		{
    		    //process content plugins
    		    $text = JHTML::_('content.prepare',$row->introtext,$cparams);
    			$lists[$i]->id = $row->id;
    			$lists[$i]->created = $row->created;
    			$lists[$i]->modified = $row->modified;
    			$lists[$i]->title = htmlspecialchars( $row->title );
    			$lists[$i]->introtext = $text;
   			    $lists[$i]->link = JRoute::_(ContentHelperRoute::getArticleRoute($row->slug, $row->catslug, $row->sectionid));
    			$i++;
    		}
        }
		return $lists;
	}
}