<?php
/**
 * @package     gantry
 * @subpackage  admin.elements
 * @version        1.5.4 November 9, 2010
 * @author        RocketTheme http://www.rockettheme.com
 * @copyright     Copyright (C) 2007 - 2010 RocketTheme, LLC
 * @license        http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 only
 *
 * Gantry uses the Joomla Framework (http://www.joomla.org), a GNU/GPLv2 content management system
 *
 */
defined('JPATH_BASE') or die();
/**
 * @package     gantry
 * @subpackage  admin.elements
 */
class JElementMultiBackgrounds extends JElement {


    function fetchElement($name, $value, &$node, $control_name) {
        global $gantry;
        $output = '';
        $document =& JFactory::getDocument();

        $this->template = $gantry->templateName;

        $class = $node->attributes('class') ? $node->attributes('class') : '';
        $preview = $node->attributes('preview') ? $node->attributes('preview') : "false";
        $path = ($node->attributes('path')) ? $node->attributes('path') : false;
        $this->default = ($node->attributes('default')) ? $node->attributes('default') : 'none';

        if (!$path) return "No path set in templateDetails.xml";

        if ($preview == 'true') $class .= " mbg-previewer";

        if (!defined('GANTRY_CSS')) {
            gantry_addStyle($gantry->gantryUrl . '/admin/widgets/gantry.css');
            define('GANTRY_CSS', 1);
        }
        if (!defined('GANTRY_MBG')) {
            gantry_addInlineScript('var GantryBackgrounds = {};');
			gantry_addInlineScript('
				GantryLang["mbg_manager"] = "' . JText::_('MBG_MANAGER') . '";
				GantryLang["mbg_desc"] = "' . JText::_('MBG_DESC') . '";
				GantryLang["mbg_avail"] = "' . JText::_('MBG_AVAIL') . '";
				GantryLang["mbg_set"] = "' . JText::_('MBG_SET') . '";
			');
			gantry_addStyle($gantry->templateUrl . '/admin/elements/css/multibackgrounds.css');
			gantry_addScript($gantry->templateUrl . '/admin/elements/js/multibackgrounds.js');
            define('GANTRY_MBG', 1);
        }

        $this->value = $value;
		$valueCount = count(explode(",", str_replace(" ", "", $value)));

        $rootPath = str_replace("__TEMPLATE__", $gantry->templatePath, $path);
        $urlPath = str_replace("__TEMPLATE__", $gantry->templateUrl, $path);

        $this->_loadGantryBackgrounds($name, $rootPath);

        $backgrounds = array();

        $__backgrounds = $gantry->retrieveTemp('backgrounds', 'backgrounds', array());
        $__paths = $gantry->retrieveTemp('backgrounds', 'paths', array());

		$backgrounds[$name] = "";
        foreach ($__backgrounds[$name] as $title => $file) {
            $backgrounds[$name] .= "'" . $file['name'] . "." . $file['ext'] . "': {'file': '" . $file['file'] . "', 'value': '" . $file['name'] . "', 'ext': '".$file['ext']."', 'name': '" . $title . "', 'path': '" . $urlPath . $file['file'] . "'}, ";
        }

        $backgrounds[$name] = substr($backgrounds[$name], 0, -2);
        gantry_addInlineScript('GantryBackgrounds["' . $name . '"] = new Hash({' . $backgrounds[$name] . '});');
		gantry_addInlineScript($this->_jsInit($name));

        $output = '
			<div class="wrapper">
				<div id="' . $name . '" class="' . $class . '">
					<a href="#" class="bg-button">
						<span class="bg-button-right">
							Manage
						</span>
					</a>
					<span class="mbg-current"><span class="mbg-current-value">'.$valueCount.'</span> backgrounds set.<br /><span class="mbg-current-total">'.count($__backgrounds[$name]).'</span> backgrounds found.</span>
					<input type="hidden" id="params' . $name . '" name="' . $control_name . '[' . $name . ']' . '" value="' . $this->value . '" />
				</div>
			</div>
		';

        $gantry->addTemp('overlays', 'overlays', $__overlays);
        $gantry->addTemp('overlays', 'paths', $__paths);

        return $output;
    }

    function _loadGantryBackgrounds($elementName, $path) {
        global $gantry;

        $backgrounds = $gantry->retrieveTemp('backgrounds', 'backgrounds', array());
        $__paths = $gantry->retrieveTemp('backgrounds', 'paths', array());

        $limit = $gantry->get('backgrounds_list_limit');
        $counter = 0;
        if (is_dir($path) && !isset($__paths[$path])) {
            if ($dh = opendir($path)) {
                $backgrounds[$elementName] = array();
                while (($file = readdir($dh)) !== false) {
                    if (filetype($path . $file) == 'file' && $this->_isImage($file)) {
                        if ($counter >= $limit) continue;

                        $ext = substr($file, strrpos($file, '.') + 1);
                        $name = substr($file, 0, strrpos($file, '.'));

                        $title = str_replace("-", " ", $name);
                        $title = ucwords($title);

                        $backgrounds[$elementName][$title] = array('name' => $name, 'ext' => $ext, 'file' => $name . "." . $ext);

                        $counter++;
                    }
                }
                closedir($dh);
                $__paths[$path] = $backgrounds[$elementName];
            }
        } else {
            $backgrounds[$elementName] = $__paths[$path];
        }

        ksort($backgrounds[$elementName]);

        $gantry->addTemp('backgrounds', 'backgrounds', $backgrounds);
        $gantry->addTemp('backgrounds', 'paths', $__paths);

        return $backgrounds;
    }

    function _isImage($file) {
        $extension = strtolower(substr($file, -4));

        return ($extension == '.jpg' || $extension == '.bmp' || $extension == '.gif' || $extension == '.png');
    }

	function _jsInit($name) {
		global $gantry;
		$mt = ($gantry->platform->jslib == 'mootools' && $gantry->platform->jslib_version == '1.1');
		$dollar = $mt ? "$('params".$name."')" : "document.id('params".$name."')";
		$setText = $mt ? "setText(" : "set('text', ";
			
		return "
			window.addEvent('domready', function() {
				".$dollar.".addEvent('set', function(value) {
					var count = value.split(',').length;
					this.value = value;
					this.getParent().getElement('.mbg-current-value').".$setText."count);
					if (Gantry.MenuItemHead) {
						var cache = Gantry.MenuItemHead.Cache[Gantry.Selection];
						if (!cache) cache = new Hash({});
						cache.set('".$name."', value);
					}
				});
			})";
		
	}
}

?>